# Preliminaries
#################

# Packages and libraries
source("PAMfmado.R")
library(gstat)
library(fields)
library(MASS)
library(maps)
library(ismev)
library(colorspace)
library(cluster)
library(geosphere)
library(nlme)

# Color palettes
pal=tim.colors
pal.qual=tim.colors




# DATA
#################
# The requested inputs : 
#	ll	: a NSx2 matrix, providing the coordinates (longitude, latitude) of each station
#	data	: a NSxNY matrix, annual max for each station / year

# Note that we assume no missing data here


# Read data (my synthetic dataset) 
load("../data/SyntheticData.RData")

# Years covered
years = as.numeric(colnames(data))

# Clausius-Clapeyron estimate
deltaT = 1	# We assume a observed 1K warming...
cc_change = (1.068^deltaT-1)	# We assume a +6.8%/K   CC-relationship

# Normalisation
rx_mean_all = apply(data,1,mean)
rxn_all = data / rx_mean_all

# Maping the mean of annual max -- Fig 2 in the paper
#	NOTE : xlim and ylim should be modified in the plot.
mm = rx_mean_all
pdf("figures/Mean_RX1d_Fig2.pdf",paper="special",width=6,height=4.5)
par(fig=c(0,.8,0,1),mar=c(3,3,1,1))
plot(ll$lon,ll$lat,type="p",xlim=c(0,1),ylim=c(0,1),xlab="",ylab="")
points(ll$lon,ll$lat,col=pal(170)[mm-30],pch=19)
points(ll$lon[mm<60],ll$lat[mm<60])
mtext("mm",side=1,at=9.3)
par(fig=c(.8,.9,0,1),mar=c(0,0,0,0),new=T)
image.plot(legend.only=TRUE,col=pal(170), zlim= c(30,200),smallplot=c(.3,.9,.15,.9))
dev.off()

# The step of selecting stations where "RX1D>threshold" is removed...
rx_mean = rx_mean_all
rxn = rxn_all
d.st.mat = t(rxn)


# Statistical analysis
##########################
# Including clustering, then stats

# Some useful functions, including make_plots()
source("Useful_functions.R")


# Clustering of stations: stations with the closest annual max time-series are put into the same cluster.
# The clustering is made for all possible number of clusters - from 1 to NS clusters, where NS is the number of measurement stations
# Here we only look at the criterion (slhouette) which measures the quality of the clustering.
SvsN=SilvsNclust(d.st.mat[,-1])


# Plot of the silhouette criterion
pdf("figures/Silhouette.pdf")
SilvsNclust(d.st.mat)
dev.off()

# Automatic selection of the number of clusters
NC = SvsN$db$nclust[which.max(SvsN$db$Sil)]


# Main analysis with NC clusters -- this produces Fig 3 and 4 of the paper
ic14.full = make_plots(NC,plot = T)	# This name was chosen because NC=14 in the original paper
ic14 = ic14.full[[1]]
d.st.mat14 = d.st.mat
ll14=ll
d.rep14 = ic14.full[[2]]

# Analyses with varying number of clusters / alternative clsutering methods (here NC = 1, 4)
ic1 = make_plots(1,plot = T)[[1]]
ic4 = make_plots(4,plot = T)[[1]]



# A few more calculations
# This includes :
# 	- Non-linear regression (NL)
#	- Analysis of trends at individual stations (Fig 6 in the paper)
source("Additional_calculations.R")


# Outputs to be used in Figure 5 -- comparison of results for (slightly) different methods
# Code for Figure 5 is not provided here...
IC = cbind(ic1,ic4,ic14)
colnames(IC) = c("ic1","ic4","ic14")
IC = as.data.frame(t(IC))

